function [labels, accuracy, value] = classifySVM(baseName, options)
% author: dino bellugi
% copyright: blueG soft wear 2010
% classifies data using trained SVM (libSVM version)
% inputs:
%   baseName = base name for files
%   options = logical(1,2) for print, save
% outputs:
%   will come soon
% example:
%   [lab, acc, val] = classifySVM('../newData/Img0057_cropped', [true true]);
% notes:
%   has some hard-coded parameters (see below)
%   expects libSVM in path:
%   addpath('../libSVM')
%   addpath('../libSVM/libsvm-mat-2.89-3')
% naming convention:
%   descriptorsName = [baseName '_descriptors']
%   modelName = [baseName '_model']
%   classifiedName = [baseName '_classified']

    %% check command line
    if (nargin < 1 || nargin > 2)
        error('Usage: [labels, accuracy, value] = classifySVM(baseName, [options])\n');
    end
    if (nargin < 2)
        options = true(2,1);
    end
    
    %% setup naming structure
    descriptorsName = [baseName '_descriptors'];
    modelName = [baseName '_model'];
    classifiedName = [baseName '_classified'];

    %% load and check data
    load(descriptorsName);
    load(modelName);
    numDesc = size(descriptors, 2);


    %% classify
    if (options(1))
        fprintf('Classifying using trained SVM ...\n');
    end
    randLabels = double(round(rand(numDesc,1)));

    tic
    [labels, accuracy, value] = svmpredict(randLabels, ...
        descriptors, svm_model, svm_opts);
    toc
    
    %% save
    if (options(2))
        if (options(1))
            fprintf('Saving classified data ...\n');
        end
        save(classifiedName, 'labels', 'accuracy', 'value');
    end

end