function S = unhookParents(S, myInd, newInd, lMode)
% travels up the path from myInd to the root of the tree
% sets siblings' parents to newInd
% if lMode, also sets nodes to not-stone
% note: myInd takes on the default value of S.current
% note: newInd takes on the default value of S.root
% note: lMode takes on the default value of true

    % check args and set defaults
    if (nargin < 1)
        error('unhookParents: insufficient parameters!\n');
    end
    if (nargin < 2)
        myInd = S.current;
    end
    if (nargin < 3)
        newInd = S.root;
    end
    if (nargin < 4 || (lMode ~= true && lMode ~= false))
        lMode = true;
    end
    
    % travel up to root
    pInd = getParent(S, myInd);
    while (pInd ~= S.root)
        % fprintf(['At node ', num2str(myInd), '\n']);
        S = setSibsParent(S, pInd, newInd);
        if (lMode)
            setValue(S, pInd, -1);
        end
        myInd = pInd;
        pInd = getParent(S, myInd);
    end
    
    % update no-stones
    S = getNoStones(S);
end

